@@ -15,12 +15,15 @@ ALL_ROUTES = [
     ('account:invoice-detail', 'SoftLayer.CLI.account.invoice_detail:cli'),
     ('account:invoices', 'SoftLayer.CLI.account.invoices:cli'),
     ('account:events', 'SoftLayer.CLI.account.events:cli'),
+    ('account:bandwidth-pools-detail', 'SoftLayer.CLI.account.bandwidth_pools_detail:cli'),
     ('account:event-detail', 'SoftLayer.CLI.account.event_detail:cli'),
+    ('account:licenses', 'SoftLayer.CLI.account.licenses:cli'),
     ('account:summary', 'SoftLayer.CLI.account.summary:cli'),
     ('account:billing-items', 'SoftLayer.CLI.account.billing_items:cli'),
     ('account:item-detail', 'SoftLayer.CLI.account.item_detail:cli'),
     ('account:cancel-item', 'SoftLayer.CLI.account.cancel_item:cli'),
     ('account:orders', 'SoftLayer.CLI.account.orders:cli'),
+    ('account:bandwidth-pools', 'SoftLayer.CLI.account.bandwidth_pools:cli'),
 
     ('virtual', 'SoftLayer.CLI.virt'),
     ('virtual:bandwidth', 'SoftLayer.CLI.virt.bandwidth:cli'),
@@ -61,6 +64,7 @@ ALL_ROUTES = [
 
     ('cdn', 'SoftLayer.CLI.cdn'),
     ('cdn:detail', 'SoftLayer.CLI.cdn.detail:cli'),
+    ('cdn:edit', 'SoftLayer.CLI.cdn.edit:cli'),
     ('cdn:list', 'SoftLayer.CLI.cdn.list:cli'),
     ('cdn:origin-add', 'SoftLayer.CLI.cdn.origin_add:cli'),
     ('cdn:origin-list', 'SoftLayer.CLI.cdn.origin_list:cli'),
@@ -101,6 +105,8 @@ ALL_ROUTES = [
     ('block:snapshot-create', 'SoftLayer.CLI.block.snapshot.create:cli'),
     ('block:snapshot-delete', 'SoftLayer.CLI.block.snapshot.delete:cli'),
     ('block:snapshot-disable', 'SoftLayer.CLI.block.snapshot.disable:cli'),
+    ('block:snapshot-set-notification', 'SoftLayer.CLI.block.snapshot.set_notify_status:cli'),
+    ('block:snapshot-get-notification-status', 'SoftLayer.CLI.block.snapshot.get_notify_status:cli'),
     ('block:snapshot-enable', 'SoftLayer.CLI.block.snapshot.enable:cli'),
     ('block:snapshot-schedule-list', 'SoftLayer.CLI.block.snapshot.schedule_list:cli'),
     ('block:snapshot-list', 'SoftLayer.CLI.block.snapshot.list:cli'),
@@ -119,6 +125,14 @@ ALL_ROUTES = [
     ('block:volume-convert', 'SoftLayer.CLI.block.convert:cli'),
     ('block:volume-set-note', 'SoftLayer.CLI.block.set_note:cli'),
 
+    ('email', 'SoftLayer.CLI.email'),
+    ('email:list', 'SoftLayer.CLI.email.list:cli'),
+    ('email:detail', 'SoftLayer.CLI.email.detail:cli'),
+    ('email:edit', 'SoftLayer.CLI.email.edit:cli'),
+
+    ('licenses', 'SoftLayer.CLI.licenses'),
+    ('licenses:create-options', 'SoftLayer.CLI.licenses.create_options:cli'),
+
     ('event-log', 'SoftLayer.CLI.event_log'),
     ('event-log:get', 'SoftLayer.CLI.event_log.get:cli'),
     ('event-log:types', 'SoftLayer.CLI.event_log.types:cli'),
@@ -138,6 +152,8 @@ ALL_ROUTES = [
     ('file:snapshot-delete', 'SoftLayer.CLI.file.snapshot.delete:cli'),
     ('file:snapshot-disable', 'SoftLayer.CLI.file.snapshot.disable:cli'),
     ('file:snapshot-enable', 'SoftLayer.CLI.file.snapshot.enable:cli'),
+    ('file:snapshot-set-notification', 'SoftLayer.CLI.file.snapshot.set_notify_status:cli'),
+    ('file:snapshot-get-notification-status', 'SoftLayer.CLI.file.snapshot.get_notify_status:cli'),
     ('file:snapshot-schedule-list', 'SoftLayer.CLI.file.snapshot.schedule_list:cli'),
     ('file:snapshot-list', 'SoftLayer.CLI.file.snapshot.list:cli'),
     ('file:snapshot-order', 'SoftLayer.CLI.file.snapshot.order:cli'),
@@ -194,6 +210,7 @@ ALL_ROUTES = [
     ('loadbal:health', 'SoftLayer.CLI.loadbal.health:cli'),
     ('loadbal:member-add', 'SoftLayer.CLI.loadbal.members:add'),
     ('loadbal:member-del', 'SoftLayer.CLI.loadbal.members:remove'),
+    ('loadbal:l7policies', 'SoftLayer.CLI.loadbal.layer7_policy_list:policies'),
     ('loadbal:pool-add', 'SoftLayer.CLI.loadbal.pools:add'),
     ('loadbal:pool-edit', 'SoftLayer.CLI.loadbal.pools:edit'),
     ('loadbal:pool-del', 'SoftLayer.CLI.loadbal.pools:delete'),
@@ -212,6 +229,10 @@ ALL_ROUTES = [
     ('nas:list', 'SoftLayer.CLI.nas.list:cli'),
     ('nas:credentials', 'SoftLayer.CLI.nas.credentials:cli'),
 
+    ('licenses', 'SoftLayer.CLI.licenses'),
+    ('licenses:create', 'SoftLayer.CLI.licenses.create:cli'),
+    ('licenses:cancel', 'SoftLayer.CLI.licenses.cancel:cli'),
+
     ('object-storage', 'SoftLayer.CLI.object_storage'),
 
     ('object-storage:accounts', 'SoftLayer.CLI.object_storage.list_accounts:cli'),
@@ -258,6 +279,7 @@ ALL_ROUTES = [
     ('hardware:dns-sync', 'SoftLayer.CLI.hardware.dns:cli'),
     ('hardware:storage', 'SoftLayer.CLI.hardware.storage:cli'),
     ('hardware:upgrade', 'SoftLayer.CLI.hardware.upgrade:cli'),
+    ('hardware:sensor', 'SoftLayer.CLI.hardware.sensor:cli'),
 
     ('securitygroup', 'SoftLayer.CLI.securitygroup'),
     ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
@@ -333,14 +355,18 @@ ALL_ROUTES = [
     ('user:vpn-subnet', 'SoftLayer.CLI.user.vpn_subnet:cli'),
 
     ('vlan', 'SoftLayer.CLI.vlan'),
+    ('vlan:create', 'SoftLayer.CLI.vlan.create:cli'),
+    ('vlan:create-options', 'SoftLayer.CLI.vlan.create_options:cli'),
     ('vlan:detail', 'SoftLayer.CLI.vlan.detail:cli'),
     ('vlan:edit', 'SoftLayer.CLI.vlan.edit:cli'),
     ('vlan:list', 'SoftLayer.CLI.vlan.list:cli'),
+    ('vlan:cancel', 'SoftLayer.CLI.vlan.cancel:cli'),
 
     ('summary', 'SoftLayer.CLI.summary:cli'),
 
     ('report', 'SoftLayer.CLI.report'),
     ('report:bandwidth', 'SoftLayer.CLI.report.bandwidth:cli'),
+    ('report:datacenter-closures', 'SoftLayer.CLI.report.dc_closures:cli'),
 
     ('autoscale', 'SoftLayer.CLI.autoscale'),
     ('autoscale:list', 'SoftLayer.CLI.autoscale.list:cli'),
