@@ -8,7 +8,7 @@
 
 import logging
 
-from SoftLayer import SoftLayerAPIError
+from SoftLayer.exceptions import SoftLayerAPIError
 from SoftLayer import utils
 
 # Invalid names are ignored due to long method names and short argument names
@@ -284,6 +284,11 @@ class AccountManager(utils.IdentifierMixin, object):
         :param string location: location string
         :returns: Routers
         """
+
+        if mask is None:
+            mask = """
+                 topLevelLocation
+               """
         object_filter = ''
         if location:
             object_filter = {
@@ -326,3 +331,38 @@ class AccountManager(utils.IdentifierMixin, object):
         _mask = """billingItem,softwareDescription"""
 
         return self.client['SoftLayer_Account'].getActiveAccountLicenses(mask=_mask)
+
+    def get_bandwidth_pools(self, mask=None):
+        """Gets all the bandwidth pools on an account"""
+
+        if mask is None:
+            mask = """mask[totalBandwidthAllocated,locationGroup, id, name, projectedPublicBandwidthUsage,
+                      billingCyclePublicBandwidthUsage[amountOut,amountIn]]
+                   """
+
+        return self.client.call('SoftLayer_Account', 'getBandwidthAllotments', mask=mask, iter=True)
+
+    def get_bandwidth_pool_counts(self, identifier):
+        """Gets a count of all servers in a bandwidth pool
+
+        Getting the server counts individually is significantly faster than pulling them in
+        with the get_bandwidth_pools api call.
+        """
+        mask = "mask[id, bareMetalInstanceCount, hardwareCount, virtualGuestCount]"
+        counts = self.client.call('SoftLayer_Network_Bandwidth_Version1_Allotment', 'getObject',
+                                  id=identifier, mask=mask)
+        total = counts.get('bareMetalInstanceCount', 0) + \
+            counts.get('hardwareCount', 0) + \
+            counts.get('virtualGuestCount', 0)
+        return total
+
+    def getBandwidthDetail(self, identifier):
+        """Gets bandwidth pool detail.
+
+        :returns: bandwidth pool detail
+        """
+        _mask = """activeDetails[allocation],projectedPublicBandwidthUsage, billingCyclePublicBandwidthUsage,
+        hardware[outboundBandwidthUsage,bandwidthAllotmentDetail[allocation]],inboundPublicBandwidthUsage,
+        virtualGuests[outboundPublicBandwidthUsage,bandwidthAllotmentDetail[allocation]],
+        bareMetalInstances[outboundBandwidthUsage,bandwidthAllotmentDetail[allocation]]"""
+        return self.client['SoftLayer_Network_Bandwidth_Version1_Allotment'].getObject(id=identifier, mask=_mask)
